@@ -1,4 +1,4 @@
-__version__ = '0.41.0'
+__version__ = '0.42.0'
 
 from json import loads
 from typing import TypedDict as _TypedDict
@@ -14,7 +14,7 @@ from pandas import read_csv as _read_csv, DataFrame as _DataFrame
 # noinspection PyUnresolvedReferences
 from pandas import to_numeric as _to_numeric, read_html as _read_html
 from aiohttp import ClientSession as _ClientSession, \
-    ClientTimeout as _ClientTimeout
+    ClientTimeout as _ClientTimeout, TCPConnector as _TCPConnector
 
 
 _csv2df = _partial(_read_csv, low_memory=False, engine='c', lineterminator=';')
@@ -101,17 +101,23 @@ def _parse_ombud_messages(text) -> _DataFrame:
 SESSION : _ClientSession | None = None
 
 
-class Session(_ClientSession):
+class Session:
+    """Create and return a ClientSession object.
 
-    def __init__(self, **kwargs):
-        if 'timeout' not in kwargs:
-            kwargs['timeout'] = _ClientTimeout(
-                total=30, sock_connect=5, sock_read=5)
-        super().__init__(**kwargs)
+    Use
+    ``ClientTimeout(total=30., sock_connect=5., sock_read=5.)``
+    as the default timeout and
+    ``TCPConnector(limit_per_host=1, keepalive_timeout=120.)``
+    as the default connector.
+    """
 
-    async def __aenter__(self):
+    def __new__(cls, *args, **kwargs) -> _ClientSession:
         global SESSION
-        SESSION = await super().__aenter__()
+        if 'timeout' not in kwargs:
+            kwargs['timeout'] = _ClientTimeout(total=30., sock_connect=5., sock_read=5.)
+        if 'connector' not in kwargs:
+            kwargs['connector'] = _TCPConnector(limit_per_host=1, keepalive_timeout=120.)
+        SESSION = _ClientSession(**kwargs)
         return SESSION
 
 
@@ -130,7 +136,7 @@ async def _get(url: str, *, fa=False) -> str | bytes:
     return content
 
 
-_DOMAIN = 'http://www.tsetmc.com/'
+_DOMAIN = 'http://tsetmc.com/'
 # API does not work on www domain
 _API = 'http://cdn.tsetmc.com/api/'
 
