@@ -1,31 +1,35 @@
 from pandas import concat as _concat, read_json as _read_json, NA as _NA
 from bs4 import BeautifulSoup as _BeautifulSoup
 
-from tsetmc import _get, _get_par_tree, _read_html, _DataFrame, _StringIO, \
+from tsetmc import _get, _get_par_tree, _numerize, _read_html, _DataFrame, \
+    _StringIO, \
     _partial
 
 
 _make_soup = _partial(_BeautifulSoup, features='lxml')
 
 
-def boards() -> dict[int, str]:
-    # Also, available at http://en.tsetmc.com/Loader.aspx?ParTree=121C1913.
-    iloc = _read_html(_get_par_tree('111C1913'), header=0)[0].iloc
+async def boards() -> dict[int, str]:
+    """See http://en.tsetmc.com/Loader.aspx?ParTree=121C1913."""
+    content = await _get_par_tree('111C1913')
+    iloc = _read_html(content, header=0)[0].iloc
     return dict(zip(iloc[:, 0], iloc[:, 1]))
 
 
-def cs_codes() -> dict[str, str]:
-    iloc = _read_html(_get_par_tree('111C1213'), header=0)[0].iloc
+async def cs_codes() -> dict[str, str]:
+    content = await _get_par_tree('111C1213')
+    iloc = _read_html(content, header=0)[0].iloc
     return dict(zip(iloc[:, 0], iloc[:, 1]))
 
 
-def industrial_groups_overview() -> _DataFrame:
+async def industrial_groups_overview() -> _DataFrame:
     """Return a dataframe of industrial groups.
 
      The result contains info about each group's price change.
      See: http://www.tsetmc.com/Loader.aspx?ParTree=111C1214
      """
-    df = _read_html(_get_par_tree('111C1214'))[0]
+    content = await _get_par_tree('111C1214')
+    df = _read_html(content)[0]
     show = df[1]
     df.drop(columns=1, inplace=True)
     percents = show.str.extract(
@@ -36,8 +40,8 @@ def industrial_groups_overview() -> _DataFrame:
     return df
 
 
-def market_map_data() -> _DataFrame:
-    text = _get('http://new.tsetmc.com/weatherforecast', fa=True)
+async def market_map_data() -> _DataFrame:
+    text = await _get('http://new.tsetmc.com/weatherforecast', fa=True)
     df: _DataFrame = _read_json(_StringIO(text), convert_dates=False)
     comma_nums = ('QTotCap', 'QTotTran5J', 'ZTotTran')
     for c in comma_nums:
@@ -47,8 +51,8 @@ def market_map_data() -> _DataFrame:
     return df
 
 
-def major_holders_activity() -> _DataFrame:
-    text = _get_par_tree('15131I')
+async def major_holders_activity() -> _DataFrame:
+    text = await _get_par_tree('15131I')
     soup = _make_soup(text)
     trs = soup.select('tr')
 
@@ -75,6 +79,15 @@ def major_holders_activity() -> _DataFrame:
     ))
 
 
+async def top_industry_groups() -> _DataFrame:
+    """http://www.tsetmc.com/Loader.aspx?Partree=15131O"""
+    text = await _get_par_tree('15131O')
+    df = _read_html(text)[0]
+    df.columns = ['group', 'mv', 'tno', 'tvol', 'tval']
+    _numerize(df, ('mv', 'tvol', 'tval'), float, comma=True)
+    return df
+
+
 def _parse_tds(tds):
     for td in tds[1:]:
         text = td.find(text=True)
